==> campsite-2.4.1.tbz: campsite/www-common/html/javascript/xinha/lang/de.js <==
// I18N constants
// LANG: "de", ENCODING: UTF-8
{
  "Bold": "Fett",
  "Italic": "Kursiv",
  "Underline": "Unterstrichen",
  "Strikethrough": "Durchgestrichen",
  "Subscript": "Tiefgestellt",
  "Superscript": "Hochgestellt",
  "Justify Left": "Linksbündig",
  "Justify Center": "Zentriert",
  "Justify Right": "Rechtsbündig",
  "Justify Full": "Blocksatz",
  "Ordered List": "Nummerierte Liste",
  "Bulleted List": "Aufzählungsliste",
  "Decrease Indent": "Einzug verkleinern",
  "Increase Indent": "Einzug vergrößern",
  "Font Color": "Schriftfarbe",
  "Background Color": "Hindergrundfarbe",
  "Horizontal Rule": "Horizontale Linie",
  "Insert Web Link": "Hyperlink einfügen",
  "Insert/Modify Image": "Bild einfügen/verändern",
  "Insert Table": "Tabelle einfügen",
  "Toggle HTML Source": "HTML Quelltext ein/ausschalten",
  "Enlarge Editor": "Editor vergrößern",
  "About this editor": "Über diesen Editor",
  "Help using editor": "Hilfe",
  "Current style": "Derzeitiger Stil",
  "Undoes your last action": "Rückgängig",
  "Redoes your last action": "Wiederholen",
  "Cut selection": "Ausschneiden",
  "Copy selection": "Kopieren",
  "Paste from clipboard": "Einfügen aus der Zwischenablage",
  "Direction left to right": "Textrichtung von Links nach Rechts",
  "Direction right to left": "Textrichtung von Rechts nach Links",
  "Remove formatting": "Formatierung entfernen",
  "Select all": "Alles markieren",
  "Print document": "Dokument ausdrucken",
  "Clear MSOffice tags": "MSOffice filter",
  "Clear Inline Font Specifications": "Zeichensatz Formatierungen entfernen",
  "Would you like to clear font typefaces?": "Wollen Sie Zeichensatztypen entfernen",
  "Would you like to clear font sizes?": "Wollen Sie Zeichensatzgrößen entfernen",
  "Would you like to clear font colours?": "Wollen sie Zeichensatzfarben entfernen",
  "Split Block": "Block teilen",
  "Toggle Borders": "Tabellenränder ein/ausblenden",
  "Save as": "speichern unter",
  "Insert/Overwrite": "Einfügen/Überschreiben",
  "&mdash; format &mdash;": "&mdash; Format &mdash;",
  "Heading 1": "Überschrift 1",
  "Heading 2": "Überschrift 2",
  "Heading 3": "Überschrift 3",
  "Heading 4": "Überschrift 4",
  "Heading 5": "Überschrift 5",
  "Heading 6": "Überschrift 6",
  "Normal": "Normal (Absatz)",
  "Address": "Adresse",
  "Formatted": "Formatiert",

  //dialogs
  "OK": "OK",
  "Cancel": "Abbrechen",
  "Path": "Pfad",
  "You are in TEXT MODE.  Use the [<>] button to switch back to WYSIWYG.": "Sie sind im Text-Modus. Benutzen Sie den [<>] Button, um in den visuellen Modus (WYSIWIG) zu gelangen.",
  "The Paste button does not work in Mozilla based web browsers (technical security reasons). Press CTRL-V on your keyboard to paste directly.": "Aus Sicherheitsgründen dürfen Skripte normalerweise nicht auf Ausschneiden/Kopieren/Einfügen zugreifen. Bitte klicken Sie OK um die technische Erläuterung auf mozilla.org zu öffnen, in der erklärt wird, wie einem Skript Zugriff gewährt werden kann.",

  "You need to select some text before create a link": "Sie müssen einen Text markieren, um einen Link zu erstellen",
  "Your Document is not well formed. Check JavaScript console for details.": "Ihr Dokument ist in keinem sauberen Format. Benutzen Sie die Javascript Console für weitere Informationen.",

  "Alignment:": "Ausrichtung:",
  "Not set": "nicht eingestellt",
  "Left": "links",
  "Right": "rechts",
  "Texttop": "oben bündig",
  "Absmiddle": "mittig",
  "Baseline": "Grundlinie",
  "Absbottom": "unten bündig",
  "Bottom": "unten",
  "Middle": "zentriert",
  "Top": "oben",

  "Layout": "Layout",
  "Spacing": "Abstand",
  "Horizontal:": "horizontal:",
  "Horizontal padding": "horizontaler Inhaltsabstand",
  "Vertical:": "vertikal:",
  "Vertical padding": "vertikaler Inhaltsabstand",
  "Border thickness:": "Randstärke:",
  "Leave empty for no border": "leer lassen für keinen Rand",

  //Insert Link
  "Insert/Modify Link": "Verknüpfung hinzufügen/ändern",
  "None (use implicit)": "k.A. (implizit)",
  "New window (_blank)": "Neues Fenster (_blank)",
  "Same frame (_self)": "Selber Rahmen (_self)",
  "Top frame (_top)": "Oberster Rahmen (_top)",
  "Other": "Anderes",
  "Target:": "Ziel:",
  "Title (tooltip):": "Titel (Tooltip):",
  "URL:": "URL:",
  "You must enter the URL where this link points to": "Sie müssen eine Ziel-URL angeben für die Verknüpfung angeben",

  // Insert Table
  "Insert Table": "Table einfügen",
  "Rows:": "Zeilen:",
  "Number of rows": "Zeilenanzahl",
  "Cols:": "Spalten:",
  "Number of columns": "Spaltenanzahl",
  "Width:": "Breite:",
  "Width of the table": "Tabellenbreite",
  "Percent": "Prozent",
  "Pixels": "Pixel",
  "Em": "Geviert",
  "Width unit": "Größeneinheit",
  "Fixed width columns": "Spalten mit fester Breite",
  "Positioning of this table": "Positionierung der Tabelle",
  "Cell spacing:": "Zellenabstand:",
  "Space between adjacent cells": "Raum zwischen angrenzenden Zellen",
  "Cell padding:": "Innenabstand:",
  "Space between content and border in cell": "Raum zwischen Inhalt und Rand der Zelle",
  "You must enter a number of rows": "Bitte geben Sie die Anzahl der Zeilen an",
  "You must enter a number of columns": "Bitte geben Sie die Anzahl der Spalten an",

  // Insert Image
  "Insert Image": "Bild einfügen",
  "Image URL:": "Bild URL:",
  "Enter the image URL here": "Bitte geben sie hier die Bild URL ein",
  "Preview": "Voransicht",
  "Preview the image in a new window": "Voransicht des Bildes in einem neuen Fenster",
  "Alternate text:": "Alternativer Text:",
  "For browsers that don't support images": "für Browser, die keine Bilder unterstützen",
  "Positioning of this image": "Positionierung dieses Bildes",
  "Image Preview:": "Bild Voransicht:",
  "You must enter the URL": "Bitte geben Sie die URL ein",

  "button_bold": "de/bold.gif",
  "button_italic": "de/italic.gif",
  "button_underline": "de/underline.gif",

  // Editor Help
  "Keyboard shortcuts": "Tastaturkürzel",
  "The editor provides the following key combinations:": "Der Editor unterstützt die folgenden kombinationen:",
  "new paragraph": "Neuer Absatz(Paragraph)",
  "insert linebreak": "Harter Umbruch einfügen",
  "Set format to paragraph": "Setze Formatierung auf Absatz",
  "Clean content pasted from Word": "Von Word eingefügter Text bereinigen",
  "Headings": "Überschrift Typ 1 bis 6",
  "Close": "Schließen"
};

==> campsite-2.6.7_5.tbz: campsite/www-common/html/javascript/xinha/lang/de.js <==
// I18N constants
// LANG: "de", ENCODING: UTF-8
{
  "Bold": "Fett",
  "Italic": "Kursiv",
  "Underline": "Unterstrichen",
  "Strikethrough": "Durchgestrichen",
  "Subscript": "Tiefgestellt",
  "Superscript": "Hochgestellt",
  "Justify Left": "Linksbündig",
  "Justify Center": "Zentriert",
  "Justify Right": "Rechtsbündig",
  "Justify Full": "Blocksatz",
  "Ordered List": "Nummerierte Liste",
  "Bulleted List": "Aufzählungsliste",
  "Decrease Indent": "Einzug verkleinern",
  "Increase Indent": "Einzug vergrößern",
  "Font Color": "Schriftfarbe",
  "Background Color": "Hindergrundfarbe",
  "Horizontal Rule": "Horizontale Linie",
  "Insert Web Link": "Hyperlink einfügen",
  "Insert/Modify Image": "Bild einfügen/verändern",
  "Insert Table": "Tabelle einfügen",
  "Toggle HTML Source": "HTML Quelltext ein/ausschalten",
  "Enlarge Editor": "Editor vergrößern",
  "About this editor": "Über diesen Editor",
  "Help using editor": "Hilfe",
  "Current style": "Derzeitiger Stil",
  "Undoes your last action": "Rückgängig",
  "Redoes your last action": "Wiederholen",
  "Cut selection": "Ausschneiden",
  "Copy selection": "Kopieren",
  "Paste from clipboard": "Einfügen aus der Zwischenablage",
  "Direction left to right": "Textrichtung von Links nach Rechts",
  "Direction right to left": "Textrichtung von Rechts nach Links",
  "Remove formatting": "Formatierung entfernen",
  "Select all": "Alles markieren",
  "Print document": "Dokument ausdrucken",
  "Clear MSOffice tags": "MSOffice filter",
  "Clear Inline Font Specifications": "Zeichensatz Formatierungen entfernen",
  "Would you like to clear font typefaces?": "Wollen Sie Zeichensatztypen entfernen",
  "Would you like to clear font sizes?": "Wollen Sie Zeichensatzgrößen entfernen",
  "Would you like to clear font colours?": "Wollen sie Zeichensatzfarben entfernen",
  "Split Block": "Block teilen",
  "Toggle Borders": "Tabellenränder ein/ausblenden",
  "Save as": "speichern unter",
  "Insert/Overwrite": "Einfügen/Überschreiben",
  "&mdash; format &mdash;": "&mdash; Format &mdash;",
  "Heading 1": "Überschrift 1",
  "Heading 2": "Überschrift 2",
  "Heading 3": "Überschrift 3",
  "Heading 4": "Überschrift 4",
  "Heading 5": "Überschrift 5",
  "Heading 6": "Überschrift 6",
  "Normal": "Normal (Absatz)",
  "Address": "Adresse",
  "Formatted": "Formatiert",

  //dialogs
  "OK": "OK",
  "Cancel": "Abbrechen",
  "Path": "Pfad",
  "You are in TEXT MODE.  Use the [<>] button to switch back to WYSIWYG.": "Sie sind im Text-Modus. Benutzen Sie den [<>] Button, um in den visuellen Modus (WYSIWIG) zu gelangen.",
  "The Paste button does not work in Mozilla based web browsers (technical security reasons). Press CTRL-V on your keyboard to paste directly.": "Aus Sicherheitsgründen dürfen Skripte normalerweise nicht auf Ausschneiden/Kopieren/Einfügen zugreifen. Bitte klicken Sie OK um die technische Erläuterung auf mozilla.org zu öffnen, in der erklärt wird, wie einem Skript Zugriff gewährt werden kann.",

  "You need to select some text before create a link": "Sie müssen einen Text markieren, um einen Link zu erstellen",
  "Your Document is not well formed. Check JavaScript console for details.": "Ihr Dokument ist in keinem sauberen Format. Benutzen Sie die Javascript Console für weitere Informationen.",

  "Alignment:": "Ausrichtung:",
  "Not set": "nicht eingestellt",
  "Left": "links",
  "Right": "rechts",
  "Texttop": "oben bündig",
  "Absmiddle": "mittig",
  "Baseline": "Grundlinie",
  "Absbottom": "unten bündig",
  "Bottom": "unten",
  "Middle": "zentriert",
  "Top": "oben",

  "Layout": "Layout",
  "Spacing": "Abstand",
  "Horizontal:": "horizontal:",
  "Horizontal padding": "horizontaler Inhaltsabstand",
  "Vertical:": "vertikal:",
  "Vertical padding": "vertikaler Inhaltsabstand",
  "Border thickness:": "Randstärke:",
  "Leave empty for no border": "leer lassen für keinen Rand",

  //Insert Link
  "Insert/Modify Link": "Verknüpfung hinzufügen/ändern",
  "None (use implicit)": "k.A. (implizit)",
  "New window (_blank)": "Neues Fenster (_blank)",
  "Same frame (_self)": "Selber Rahmen (_self)",
  "Top frame (_top)": "Oberster Rahmen (_top)",
  "Other": "Anderes",
  "Target:": "Ziel:",
  "Title (tooltip):": "Titel (Tooltip):",
  "URL:": "URL:",
  "You must enter the URL where this link points to": "Sie müssen eine Ziel-URL angeben für die Verknüpfung angeben",

  // Insert Table
  "Insert Table": "Table einfügen",
  "Rows:": "Zeilen:",
  "Number of rows": "Zeilenanzahl",
  "Cols:": "Spalten:",
  "Number of columns": "Spaltenanzahl",
  "Width:": "Breite:",
  "Width of the table": "Tabellenbreite",
  "Percent": "Prozent",
  "Pixels": "Pixel",
  "Em": "Geviert",
  "Width unit": "Größeneinheit",
  "Fixed width columns": "Spalten mit fester Breite",
  "Positioning of this table": "Positionierung der Tabelle",
  "Cell spacing:": "Zellenabstand:",
  "Space between adjacent cells": "Raum zwischen angrenzenden Zellen",
  "Cell padding:": "Innenabstand:",
  "Space between content and border in cell": "Raum zwischen Inhalt und Rand der Zelle",
  "You must enter a number of rows": "Bitte geben Sie die Anzahl der Zeilen an",
  "You must enter a number of columns": "Bitte geben Sie die Anzahl der Spalten an",

  // Insert Image
  "Insert Image": "Bild einfügen",
  "Image URL:": "Bild URL:",
  "Enter the image URL here": "Bitte geben sie hier die Bild URL ein",
  "Preview": "Voransicht",
  "Preview the image in a new window": "Voransicht des Bildes in einem neuen Fenster",
  "Alternate text:": "Alternativer Text:",
  "For browsers that don't support images": "für Browser, die keine Bilder unterstützen",
  "Positioning of this image": "Positionierung dieses Bildes",
  "Image Preview:": "Bild Voransicht:",
  "You must enter the URL": "Bitte geben Sie die URL ein",

  "button_bold": "de/bold.gif",
  "button_italic": "de/italic.gif",
  "button_underline": "de/underline.gif",

  // Editor Help
  "Keyboard shortcuts": "Tastaturkürzel",
  "The editor provides the following key combinations:": "Der Editor unterstützt die folgenden kombinationen:",
  "new paragraph": "Neuer Absatz(Paragraph)",
  "insert linebreak": "Harter Umbruch einfügen",
  "Set format to paragraph": "Setze Formatierung auf Absatz",
  "Clean content pasted from Word": "Von Word eingefügter Text bereinigen",
  "Headings": "Überschrift Typ 1 bis 6",
  "Close": "Schließen",

  // Loading messages
  "Loading in progress. Please wait !": "Editor wird geladen. Bitte warten !",
  "Constructing main object": "Hauptteil wird erzeugt",
  "Create Toolbar": "Bearbeitungswerkzeuge werden angelegt",
  "Register panel right": "Erzeugt rechte Leiste",
  "Register panel left": "Erzeugt linke Leiste",
  "Register panel top": "Erzeugt obere Leiste",
  "Register panel bottom": "Erzeugt untere Leiste"
};
